Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeploymentCommand ¶
DeploymentCommand is used to generate the kubernetes deployment yaml files.
func GenTemplates ¶
GenTemplates generates the deployment template files.
func RevertTemplate ¶
RevertTemplate reverts the given template file to the default value.
Types ¶
type Deployment ¶
type Deployment struct {
Name string
Namespace string
Image string
Secret string
Replicas int
Revisions int
Port int
NodePort int
UseNodePort bool
RequestCpu int
RequestMem int
LimitCpu int
LimitMem int
MinReplicas int
MaxReplicas int
ServiceAccount string
}
Deployment describes the k8s deployment yaml
Click to show internal directories.
Click to hide internal directories.